@@ -16,9 +16,13 @@ this program. If not, see <https://www.gnu.org/licenses/>.
 from flask import Flask
 
 from ibkr_report import cron, website
+from ibkr_report.exchangerates import ExchangeRates
+from ibkr_report.report import Report
+
+__all__ = ["create_app", "ExchangeRates", "Report"]
 
 
-def create_app():
+def create_app() -> Flask:
     """Create and configure an instance of the Flask application."""
     app = Flask(__name__)
     app.register_blueprint(cron.bp)
