@@ -1,3 +1,5 @@
+"""Cron jobs"""
+
 from flask import Blueprint, abort, request
 
 from ibkr_report.definitions import BUCKET_ID
@@ -8,10 +10,11 @@ bp = Blueprint("cron", __name__)
 
 
 @bp.route("/cron", methods=["GET"])
-def cron():
+def cron() -> str:
     """Cron function that fetches the latest exchange rates if necessary."""
     if request.headers.get("X-Appengine-Cron") is None:
         abort(403)
     if BUCKET_ID:
         _ = ExchangeRates(cron_job=True)
-    return "Done!"
+        return "Done!"
+    return "BUCKET_ID missing!"
